#!/usr/bin/env python3

"""
Module: taz

Trivial Azure API

Subpackages:
    - taz[blob]
    - taz[dev]
    - taz[dls]
    - taz[aci]
    - taz[auth]

Submodules:
    - taz.keyvault
    - taz.auth
    - taz.acr
    - taz.aci
    - taz.blob (use Azure storage SDK v12)
    - taz.dls

Copyright (C) 2018-2020, Christophe Fauchard
"""

import sys
from taz._version import __version__, __version_info__

__author__ = "Christophe Fauchard <christophe.fauchard@gmail.com>"

if sys.version_info < (3, 6):
    raise RuntimeError("You need Python 3.6+ for this module.")



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from azure.keyvault.secrets import SecretClient
from azure.identity import (
    DefaultAzureCredential,
    ChainedTokenCredential,
    ClientSecretCredential,
    ManagedIdentityCredential,
    InteractiveBrowserCredential,
)
import os


class KeyVault:

    """create keyvault object azure.keyvault.secrets

    parameters:
        - name: keyvault name

    attributes:
        - client (azure.keyvault.secrets.SecretClient): Azure Secrets Keyvault client
        - name (string): keyvault name
        - mode (string): connection mode based on environment vars
        AZURE_TENANT_ID, AZURE_CLIENT_ID, AZURE_CLIENT_SECRET and AZURE_CLI_USER
            - service_proicipal: service principal authentication if AZURE_CLIENT_SECRET is set
            - cli_profile: CLI based authentication if AZURE_CLI_USER var is set
            - msi: MSI otherwise
    """

    def __init__(self, name):
        self.name = name

        self.tenant_id = os.environ.get("AZURE_TENANT_ID")
        self.client_id = os.environ.get("AZURE_CLIENT_ID")
        self.cli_user = os.environ.get("AZURE_CLI_USER")

        if os.environ.get("AZURE_CLIENT_SECRET"):
            credentials = self._get_sp_credentials(
                self.tenant_id, self.client_id, os.environ.get("AZURE_CLIENT_SECRET")
            )
        elif self.client_id:
            credentials = self._get_user_msi_credentials(self.client_id)
        elif self.cli_user:
            credentials = self._get_cli_profile_credentials()
        else:
            credentials = self._get_system_msi_credentials()

        self.client = SecretClient(
            "https://{}.vault.azure.net/".format(self.name), credentials
        )

    def _get_cli_profile_credentials(self):
        self.mode = "cli_profile"
        return InteractiveBrowserCredential()

    def _get_system_msi_credentials(self):
        self.mode = "system_msi"
        return ManagedIdentityCredential()

    def _get_user_msi_credentials(self, client_id):
        self.mode = "user_msi"
        return ManagedIdentityCredential(client_id=client_id)

    def _get_sp_credentials(self, tenant_id, client_id, client_secret):
        self.mode = "service_principal"
        return ClientSecretCredential(tenant_id, client_id, client_secret)

    def get_secret(self, secret_id, secret_version=""):
        """
        get secret value of a specified secret

        parameters:
            - secret_id: name or url of the secret
            - secret_version: version to retrieve

        return:
            -  azure.keyvault.secrets.Secret object
                - value: secret value
                - SecretProperties: secret metadatas (azure.keyvault.secrets.SecretProperties object)
        """

        return self.client.get_secret(secret_id, secret_version)

    def set_secret(self, secret_id, value):
        """
        set secret specified

        parameters:
            - secret_id: name of secret to set
            - value: secret value to set

        return:
            - none
        """
        self.client.set_secret(secret_id, value)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from taz.blob import StorageAccount, Blob, Container
import tests.config as cfg
import sys


class BlobTests(unittest.TestCase):
    def setUp(self):
        self.storage_account_name = cfg.blob["storage_account_name"]
        self.storage_key = cfg.blob["storage_key"]
        self.storage_connection_string = cfg.blob["storage_connection_string"]
        self.sas_key = cfg.blob["sas_key"]
        self.sas_url = cfg.blob["sas_url"]
        self.container_name = cfg.blob["container_name"]
        self.path = cfg.blob["path"]
        self.sas_url_path = cfg.blob["sas_url_path"]
        self.sas_key_path = cfg.blob["sas_key_path"]
        self.localpath = cfg.blob["localpath"]
        self.gzip_path = cfg.blob["gzip_path"]
        self.data = cfg.blob["data"]

    def test_010_get_storage_account(self):
        self.storage_account = StorageAccount(
            self.storage_account_name,
            key=self.storage_key,
            connection_string=self.storage_connection_string,
        )
        self.assertTrue(self.storage_account is not None)

    def test_012_get_container(self):
        self.test_010_get_storage_account()
        self.container = Container(self.storage_account, self.container_name)

    def test_013_get_container_properties(self):
        self.test_010_get_storage_account()
        self.container = Container(self.storage_account, self.container_name)
        print(self.container.get_properties())

    def test_020_list_containers(self):
        self.test_010_get_storage_account()
        self.containers = self.storage_account.list_containers()
        for container in self.containers:
            print(container.name)
        self.assertTrue(self.containers is not None)

    def test_040_get_blob(self):
        self.test_010_get_storage_account()
        self.blob = Blob(
            self.container_name, self.path, storage_account=self.storage_account
        )
        self.assertTrue(self.blob is not None)

    def test_042_get_gzip_blob(self):
        self.test_010_get_storage_account()
        self.gzip_blob = Blob(
            self.container_name, self.gzip_path, storage_account=self.storage_account
        )
        self.assertTrue(self.gzip_blob is not None)

    def test_043_get_blob_by_sas_url(self):
        self.sas_url_blob = Blob(
            self.container_name, self.sas_url_path, sas_url=self.sas_url
        )

    def test_044_get_blob_by_sas_key(self):
        self.sas_key_blob = Blob(
            self.container_name,
            self.sas_key_path,
            sas_key=self.sas_key,
            storage_account_name=self.storage_account_name,
        )

    def test_045_blob_write(self):
        self.test_040_get_blob()
        self.blob.write(bytes(self.data, "utf-8"))

    def test_046_blob_write_sas_url(self):
        self.test_043_get_blob_by_sas_url()
        self.sas_url_blob.write(bytes(self.data, "utf-8"))

    def test_046_blob_write_sas_key(self):
        self.test_044_get_blob_by_sas_key()
        self.sas_key_blob.write(bytes(self.data, "utf-8"))

    def test_048_blob_gzip_write(self):
        self.test_042_get_gzip_blob()
        self.gzip_blob.gzip_write(bytes(self.data, "utf-8"))

    def test_049_list_blobs(self):
        self.test_010_get_storage_account()
        self.test_012_get_container()
        self.blobs = self.container.list_blobs()
        for blob in self.blobs:
            print(blob.name)
        self.assertTrue(self.blobs is not None)

    def test_050_get_blob_sas_token(self):
        self.test_040_get_blob()
        self.sas_token = self.blob.get_sas_token()
        print(self.blob.sas_token)
        self.assertTrue(self.sas_token is not None)

    def test_060_get_blob_url(self):
        self.test_040_get_blob()
        self.url = self.blob.get_url()
        print(self.url)
        self.assertTrue(self.url is not None)

    def test_070_blob_read_raw(self):
        self.test_040_get_blob()
        data = self.blob.read()
        print(data)
        self.assertTrue(data is not None)

    def test_070_blob_download(self):
        self.test_040_get_blob()
        print(self.blob.name)
        print(self.localpath)
        self.blob.download(self.localpath)

    def test_070_blob_upload(self):
        self.test_040_get_blob()
        print(self.blob.name)
        print(self.localpath)
        self.blob.upload(self.localpath)

    def test_080_blob_read_csv(self):
        self.test_040_get_blob()
        self.csv_datas = self.blob.read_csv()
        print(self.csv_datas)
        self.assertTrue(self.csv_datas is not None)

    def test_090_blob_read_gzip_csv(self):
        self.test_042_get_gzip_blob()
        print(self.gzip_blob.get_url())
        self.csv_datas = self.gzip_blob.read_csv(compression="gzip")
        print(self.csv_datas)
        self.assertTrue(self.csv_datas is not None)

    def test_100_blob_delete(self):
        self.test_040_get_blob()
        self.blob.delete()

    def test_110_gzip_blob_delete(self):
        self.test_042_get_gzip_blob()
        self.gzip_blob.delete()

    def test_120_blob_sas_url_delete(self):
        self.test_043_get_blob_by_sas_url()
        self.sas_url_blob.delete()

    def test_130_blob_ss_key_delete(self):
        self.test_044_get_blob_by_sas_key()
        self.sas_key_blob.delete()

    # WARNING: do not delete conatiner for aci logs save test to pass
    #
    # def test_140_container_delete(self):
    #     self.storage_account = StorageAccount(
    #         self.storage_account_name,
    #         key=self.storage_key,
    #         connection_string=self.storage_connection_string,
    #     )
    #     self.container = Container(self.storage_account, self.container_name)
    #     self.container.delete()


if __name__ == "__main__":
    sys.argv.append("-v")
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Taz library: blobs operations

Examples:

get blob from sas key:

    blob = Blob(
        <container>, 
        <name>, 
        storage_account_name=<storage account_name
        sas_key=<sas key>)

get blob from sas url:

    blob = Blob(
        <container>, 
        <name>, 
        sas_url=<sas url>)

"""
import urllib
from azure.core.exceptions import ResourceExistsError

from azure.storage.blob import (
    BlobServiceClient,
    BlobClient,
    ContainerClient,
    BlobType,
    BlobSasPermissions,
    generate_blob_sas,
)
from datetime import datetime, timedelta
import pandas as pd
import gzip

from taz.exception import BlobAthenticationFailedException


class StorageAccount:
    def __init__(self, name, key=None, connection_string=None):
        """ Storage account object

        Args:
            name (TYPE): Description
            storage_key (None, optional): Description
        """

        self.name = name
        self.key = key
        self.connection_string = connection_string

        self.blob_service_client = BlobServiceClient.from_connection_string(
            self.connection_string
        )

    def list_containers(self, prefix=None):
        """ list storage account containers

        Returns:
            - azure.storage.blob.models.Container List: list of container, Container class attributes:
                - name
                - metadata
                - properties
        """
        return self.blob_service_client.list_containers(name_starts_with=prefix)


class Container:
    def __init__(self, storage_account, name):
        """ define Container object 

        Args:
            storage_account (TYPE): Description
            name (TYPE): Description
        """
        self.storage_account = storage_account
        self.name = name

        try:
            self.client = self.storage_account.blob_service_client.create_container(
                self.name
            )
        except ResourceExistsError:
            self.client = self.storage_account.blob_service_client.get_container_client(
                self.name
            )

    def get_properties(self):
        return self.client.get_container_properties()

    def delete(self):
        return self.storage_account.blob_service_client.delete_container(self.name)

    def list_blobs(self, prefix=None):
        return self.client.list_blobs(name_starts_with=prefix)


class Blob:
    def __init__(
        self,
        container,
        name,
        sas_url=None,
        sas_key=None,
        storage_account_name=None,
        storage_account=None,
    ):
        """define blob object
        
        :param container: container name
        :type container: str
        :param name: blob name
        :type name: str
        :param sas_url: sas url, defaults to None
        :type sas_url: str, optional
        :param sas_key: sas key (needs storage_account_name), defaults to None
        :type sas_key: str, optional
        :param storage_account_name: storage account name, defaults to None
        :type storage_account_name: str, optional
        :param storage_account: storage account object, defaults to None
        :type storage_account: taz.blob.StorageAccount, optional
        """
        self.storage_account = storage_account
        self.container = container
        self.name = name
        self.sas_url = sas_url
        self.storage_account = storage_account
        self.sas_key = sas_key
        self.storage_account_name = storage_account_name

        if self.storage_account:
            self.auth_mode = "storage_account_connection_string"
            self.client = self.storage_account.blob_service_client.get_blob_client(
                self.container, self.name
            )
        elif self.sas_url:
            self.auth_mode = "sas_url"
            self.client = BlobServiceClient(sas_url).get_blob_client(
                self.container, self.name
            )
        elif self.sas_key and self.storage_account_name:
            self.auth_mode = "sas_key"
            self.client = BlobServiceClient(
                "https://{}.blob.core.windows.net/{}".format(
                    self.storage_account_name, self.sas_key
                )
            ).get_blob_client(self.container, self.name)
        else:
            raise (BlobAthenticationFailedException(self.name))

    def get_sas_token(self):
        permission = BlobSasPermissions.from_string("racwd")

        self.sas_token = generate_blob_sas(
            self.storage_account.name,
            self.container,
            self.name,
            account_key=self.storage_account.key,
            permission=permission,
            expiry=datetime.utcnow() + timedelta(hours=1),
        )
        return self.sas_token

    def get_url(self):
        return "{}?{}".format(self.client.url, self.get_sas_token())

    def read(self):
        """read datas from blob
        
        :return: data read
        :rtype: binary string
        """
        return self.client.download_blob().readall()

    def read_csv(self, **kargs):
        """read CSV file from Blob

        Args:
            - path (string): remote csv file path to read
            - **kargs: arguments array passed to pandas.read_csv

        Returns:
            - pandas.DataFrame: DataFrame filled with read datas
        """

        return pd.read_csv(self.get_url(), **kargs)

    def gzip_write(self, data, overwrite=True):
        """write gzipped data to blob
        
        :param data: datas to write
        :type data: binary string
        :param overwrite: overwrite or not, defaults to True
        :type overwrite: bool, optional
        """
        return self.write(gzip.compress(data, compresslevel=9), overwrite=overwrite)

    def write(self, data, overwrite=True):
        return self.client.upload_blob(data, overwrite=overwrite)

    def upload(self, path, overwrite=True):
        """upload file to blob
        
        :param path: local path
        :type path: str
        :param overwrite: overwrite blob or not, defaults to True
        :type overwrite: bool, optional
        """
        with open(path, "rb") as data:
            self.write(data, overwrite=True)

    def download(self, path):
        with open(path, "wb") as data:
            data.write(self.read())

    def delete(self):
        return self.client.delete_blob()




keyvault = {
    name: "kvdvldev"
    secret_name: "REGISTRY-PASSWORD"
    tenant_id: "4a7c8238-5799-4b16-9fc6-9ad8fce5a7d9"
    client_id: "9d6f83f7-af2f-4a8d-b692-e2329dbbef9d"
    client_secret: "<secured string>"
}

auth = {
    resource_group: "RG-APPLI-RED-DEV"
    managed_identity: "mi-aci-wag-dev-01"
    subscription_id: "5f82da32-5cad-49a4-aec5-5ba8806e6d9c"
    tenant_id: "4a7c8238-5799-4b16-9fc6-9ad8fce5a7d9"
    client_id: "1300f1b6-1bc2-4658-a504-86a1850805d2"
    client_secret: "<secured string>"
}

blob = {
    storage_account_name: "zstalrsdvllogdev01"
    storage_key: "<secured string>"
    storage_connection_string: "<secured string>"
    sas_key: "<secured string>"
    sas_url: "https://zstalrsdvllogdev01.blob.core.windows.net/?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2021-04-05T00:06:34Z&st=2020-04-04T16:06:34Z&spr=https&sig=pfpsr7LS6OBBAJdeNNegP9SUYSCF2yDwqFr8SZ3hS5M%3D"
    container_name: "unittest-taz"
    path: "test.csv"
    sas_url_path: "test_sas_url.csv"
    sas_key_path: "test_sas_key.csv"
    localpath: "/tmp/test.csv"
    gzip_path: "test.csv.gz"
    data: "col1,col2,col3
val11,val12,val13
val21,val22,val23"
}

acr = {
    resource_group: "RG-APPLI-RED-DEV"
    registry_name: "crreddev"
    subscription_id: "5f82da32-5cad-49a4-aec5-5ba8806e6d9c"
    image_name: "hello-world"
}

aci = {
    resource_group: "RG-APPLI-RED-DEV"
    container_group_name: "cg-taz-test-unit"
    location: "northeurope"
    subscription_id: "5f82da32-5cad-49a4-aec5-5ba8806e6d9c"
    logs_sas_key: "?sv=2019-02-02&ss=bfqt&srt=sco&sp=rwdlacup&se=2021-04-05T02:04:07Z&st=2020-04-04T18:04:07Z&spr=https&sig=gcK6vxvENtBnXfCfVj7nPxdSsQYcY4rS4W740fTKA80%3D"
    logs_container: "unittest-taz"
    logs_storage_account: "zstalrsdvllogdev01"
}

dls = {
    dls_name: "lemanhprod"
    tenant_id: "4a7c8238-5799-4b16-9fc6-9ad8fce5a7d9"
    client_id: "e3952129-496b-416b-a244-67c43bd5bddd"
    client_secret: "<secured string>"
    https_proxy: "localhost:3128"
    path: "SNCF/landing/input/METEOFRANCE/data_files/OBSERVATIONS_5MN/2019"
    glob_path: "SNCF/landing/input/METEOFRANCE/data_files/OBSERVATIONS_5MN/2019/matriceSNCF_20191212*"
    file_name: "matriceSNCF_201905201520.csv"
    gz_file_name: "SNCF/landing/input/METEOFRANCE/data_files/PREVISIONS/20190123/previsions_20190123_J1.csv.gz"
    tmp_file_name: "/tmp/taz.tmp"
}

dls_glob = {
}



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import unittest
from taz.aci import SimpleContainerGroup
from taz.acr import ContainerRegistry
from taz.acr import ContainerImage
import tests.config as cfg
import sys


class AciDeleteTests(unittest.TestCase):
    def setUp(self):

        self.container_group = SimpleContainerGroup(
            cfg.aci["container_group_name"], cfg.aci["resource_group"],
        )

    def test_10_exists(self):
        self.assertTrue(self.container_group is not None)
        print(self.container_group)

    def test_20_list_delete(self):
        self.container_group.delete()


if __name__ == "__main__":
    sys.argv.append("-v")
    unittest.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from azure.common.client_factory import get_client_from_cli_profile
from azure.mgmt.msi import ManagedServiceIdentityClient
from azure.mgmt.containerinstance.models import ContainerGroupIdentity
from msrestazure.azure_active_directory import MSIAuthentication
from azure.common.credentials import ServicePrincipalCredentials

import os
import json


class GenericClient:
    """Class GenericClient
    
    Attributes:
        - client_class (Class): Client class to build
        - tenant_id (string): Azure tenant id
        - subscription_id (string): Azure subscription id
        - client id (string): Azure client id
        - client_secret (string): Azure client secret
        - cli_profile (string): use cli profile if not None
        - mode (string): auth mode
            choice in this order:
            - cli_profile not None => cli profile authentication
            - client_secret not None => service principal authentication

    Environment variables:
        if corresponding attributes not set, read env vars:
        AZURE_TENANT_ID, AZURE_CLIENT_ID, AZURE_CLIENT_SECRET and AZURE_CLI_PROFILE
    """

    def __init__(
        self,
        client_class,
        tenant_id=None,
        subscription_id=None,
        client_id=None,
        client_secret=None,
        cli_profile=None,
    ):
        """GenericClient Constructor
        
        :param client_class: client class to build
        :type client_class: class
        :param tenant_id: Azure tenant id, defaults to None
        :type tenant_id: string, optional
        :param subscription_id: Azure subscription id, defaults to None
        :type subscription_id: string, optional
        :param client_id: Azure client id, defaults to None
        :type client_id: string, optional
        :param client_secret: client secret, defaults to None
        :type client_secret: string, optional
        :param cli_profile: cli profile (None or else), defaults to None
        :type cli_profile: string, optional
        :return: Generic Azure Client Class
        :rtype: GenericClient
        """
        self.client_class = client_class

        if tenant_id:
            self.tenant_id = tenant_id
        else:
            self.tenant_id = os.environ.get("AZURE_TENANT_ID")

        if subscription_id:
            self.subscription_id = subscription_id
        else:
            self.subscription_id = os.environ.get("AZURE_SUBSCRIPTION_ID")

        if client_id:
            self.client_id = client_id
        else:
            self.client_id = os.environ.get("AZURE_CLIENT_ID")

        if client_secret:
            self.client_secret = client_secret
        else:
            self.client_secret = os.environ.get("AZURE_CLIENT_SECRET")

        if cli_profile:
            self.cli_profile = cli_profile
        else:
            self.cli_profile = os.environ.get("AZURE_CLI_PROFILE")

        if self.cli_profile:
            self.mode = "cli_profile"
        elif self.client_secret:
            self.mode = "service_principal"
        else:
            self.mode = "msi"

    def get_client(self):
        """get Azure Client class
        
        :return: Azure Client Class
        :rtype: class
        """
        if self.mode == "service_principal":
            self.client = self.client_class(
                ServicePrincipalCredentials(
                    client_id=self.client_id,
                    secret=self.client_secret,
                    tenant=self.tenant_id,
                ),
                subscription_id=self.subscription_id,
            )
            return self.client
        elif self.mode == "cli_profile":
            self.client = get_client_from_cli_profile(
                self.client_class, subscription_id=self.subscription_id
            )
            return self.client
        else:
            self.client = self.client_class(
                MsiAuthentication(), subscription_id=self.subscription_id
            )
            return self.client


class UserAssignedIdentity:

    """User Assigned identity
    
    Attributes:
        - client (ManagedServiceIdentityClient): MSI client
        - container_group_identity (ContainerGroupIdentity): identity to use
        with container group
        - identity (TYPE): Description
        - managed_identity_name (TYPE): Description
        - resource_group_name (string): Resource Group
        - subscription_id (string): subscription id
    """

    def __init__(
        self, resource_group_name, managed_identity_name, subscription_id=None
    ):
        """
        Create a user assigned identity object

        Args:
            resource_group (string): resource group name
            managed_identity (string): managed identity name
            subscription_id (None, optional): subscription id (if None default)
        """

        generic_client = GenericClient(
            ManagedServiceIdentityClient, subscription_id=subscription_id
        )
        self.client = generic_client.get_client()

        self.subscription_id = subscription_id
        self.resource_group_name = resource_group_name
        self.managed_identity_name = managed_identity_name
        self.identity = self.get_identity()

    def get_identity(self):
        self.identity = self.client.user_assigned_identities.get(
            self.resource_group_name, self.managed_identity_name
        )

        return self.identity

    def get_container_group_identity(self):
        self.get_identity()

        self.container_group_identity = ContainerGroupIdentity(
            type="UserAssigned", user_assigned_identities={self.identity.id: {}}
        )
        return self.container_group_identity

    def __str__(self):
        return json.dumps(
            {
                "id": self.identity.id,
                "name": self.identity.name,
                "tenant_id": self.identity.tenant_id,
                "principal_id": self.identity.principal_id,
                "client_id": self.identity.client_id,
                "type": self.identity.type,
            },
            indent=4,
        )


class MsiAuthentication:
    def __init__(self):
        self.credentials = MSIAuthentication()

    def get_credentials(self):
        return self.credentials


class ClientSecretAuthentication:
    def __init__(
        self, tenant_id=None, subscription_id=None, client_id=None, client_secret=None
    ):
        """Client/Client secret authentication
        
        :param tenant_id: tenant_id or AZURE_TENANT_ID env var, defaults to None
        :type tenant_id: string, optional
        :param subscription_id: subscription_id or AZURE_SUBSCRIPTION_ID env var, defaults to None
        :type subscription_id: string, optional
        :param client_id: client_id or AZURE_CLIENT_ID env var, defaults to None
        :type client_id: string, optional
        :param client_secret: client_secret or AZURE_CLIENT_SECRET env var, defaults to None
        :type client_secret: string, optional
        """
        if tenant_id is None:
            self.tenant_id = os.environ.get("AZURE_TENANT_ID")
        else:
            self.tenant_id = tenant_id

        if subscription_id is None:
            self.subscription_id = os.environ.get("AZURE_SUBSCRIPTION_ID")
        else:
            self.subscription_id = subscription_id

        if client_id is None:
            self.client_id = os.environ.get("AZURE_CLIENT_ID")
        else:
            self.client_id = client_id

        if client_secret is None:
            self.client_secret = os.environ.get("AZURE_CLIENT_SECRET")
        else:
            self.client_secret = client_secret

        self.credentials = ServicePrincipalCredentials(
            tenant=self.tenant_id, client_id=self.client_id, secret=self.client_secret
        )

    def get_credentials(self):
        return self.credentials



#!/usr/bin/env python
# -*- coding: utf-8 -*-


class ContainerAlreadyExistsException(Exception):
    def __init__(self, container_name):
        self.container_name = container_name


class BlobAthenticationFailedException(Exception):
    def __init__(self, blob_name):
        self.blob_name = blob_name
